%% Convert B88 results to NetCDF
% NOTE: This requires the SNCTools, which is a third party package
%   that is available from Mathworks. The NetCDF files could probably
%   be written using a different package.

clear

% Define input files 
% (Note, "nsim" is set up this way in case there are multiple directories)
b88dir = '.' ; 
cd(b88dir) ; 
b88_runs = {'.'} ; 
nsim = length(b88_runs) ; 

% Define output files
outdir = './NetCDF' ; 
eval(['! mkdir -p ' outdir]) ; 

% Get lat and lon indices
blon = [127:6:277] ; 
nlon = length(blon) ; 
blat = [-29:2:29] ; 
nlat = length(blat) ; 
nyr = 100 ; ntim = 12*nyr ; 

% Initialize input arrays
ssta = nan(nsim, 12, nlat, nlon) ; 
uwnda = nan(nsim, 12, nlat, nlon) ; 
vwnda = nan(nsim, 12, nlat, nlon) ; 
tca = nan(nsim, 12, nlat, nlon) ; 

% Load data
for irun = 1:nsim ; 
    
    ssttem = load(fullfile(b88dir, b88_runs{irun}, 'model.temp.ano1')) ; 
    windtem = load(fullfile(b88dir, b88_runs{irun}, 'model.wind.ano1')) ; 
    tctem = load(fullfile(b88dir, b88_runs{irun}, 'model.hfield.ano1')) ; 
    sst = nan(ntim, nlat, nlon) ; 
    uwnd = sst ; 
    vwnd = sst ; 
    tc = sst ;

    % Unpack B88 data
    for i = 1:ntim ; 
        ind1 = 30*(i-1)+[1:30] ; 
        ind2 = 60*(i-1)+[1:30] ; 
        sst(i,:,:) = ssttem(ind1,:,:) ; 
        uwnd(i,:,:) = windtem(ind2,:,:) ; 
        vwnd(i,:,:) = windtem(ind2+30,:,:) ; 
        tc(i,:,:) = tctem(ind1,:,:) ; 
    end

    % Kee last 50yrs only
    yrkp = (50*12+1):ntim ; 
    [tem, ssta(irun,:,:,:)] = remove_anncyc(sst(yrkp,:,:)) ; 
    [tem, uwnda(irun,:,:,:)] = remove_anncyc(uwnd(yrkp,:,:)) ; 
    [tem, vwnda(irun,:,:,:)] = remove_anncyc(vwnd(yrkp,:,:)) ;
    [tem, tca(irun,:,:,:)] = remove_anncyc(tc(yrkp,:,:)) ; 
    
end

%% Now, write to NetCDF file
    
sstdat = ssta ; 
uwnddat = uwnda ; 
vwnddat = vwnda ; 
tcdat = tca ; 

nlon = length(blon) ; 
nlat = length(blat) ; 

dpm = [31 28 31 30 31 30 31 31 30 31 30 31] ; 
cdpm = cumsum([0 dpm(1:(end-1))])+dpm/2 ; 

filout_tot = {'B88_Coup_SOMforced.nc'} ; 

for i = 1:nsim
filout = fullfile(outdir, filout_tot{i}) ; 
nc_create_empty(filout) ; 
    nc_adddim(filout,'lat',nlat);
    nc_adddim(filout,'lon',nlon);
    nc_adddim(filout,'time',0);

    v1.Name = 'time' ; 
    v1.Datatype = 'double' ; 
    v1.Dimension = {'time'} ; 
    nc_addvar(filout, v1) ; 
    nc_varput(filout, 'time', cdpm) ; 
    
    v1.Name = 'lon' ; 
    v1.Datatype = 'double' ; 
    v1.Dimension = {'lon'} ; 
    nc_addvar(filout, v1) ; 
    nc_varput(filout, 'lon', blon) ; 
    
    v1.Name = 'lat' ; 
    v1.Datatype = 'double' ; 
    v1.Dimension = {'lat'} ; 
    nc_addvar(filout, v1) ; 
    nc_varput(filout, 'lat', blat) ; 
    
    v1.Name = 'TS' ; 
    v1.Datatype = 'double' ; 
    v1.Dimension = {'time', 'lat', 'lon'} ; 
    nc_addvar(filout, v1) ;
    nc_varput(filout, v1.Name, squeeze(sstdat(i,:,:,:))) ; 
    nc_attput(filout, v1.Name, 'units', '^oC') ; 
    nc_attput(filout, v1.Name, 'longname', 'SST') ; 
    nc_attput(filout, v1.Name, 'Notes', 'Annual mean is NOT removed')
    
    v1.Name = 'U' ; 
    v1.Datatype = 'double' ; 
    v1.Dimension = {'time', 'lat', 'lon'} ; 
    nc_addvar(filout, v1) ; 
    nc_varput(filout, v1.Name, squeeze(uwnddat(i,:,:,:))) ; 
    nc_attput(filout, v1.Name, 'units', 'm sec^-^1') ; 
    nc_attput(filout, v1.Name, 'longname', 'UWND') ; 
    nc_attput(filout, v1.Name, 'Notes', 'Forced or Coupled Response Only; Annual mean is NOT removed')
    
    v1.Name = 'V' ; 
    v1.Datatype = 'double' ; 
    v1.Dimension = {'time', 'lat', 'lon'} ; 
    nc_addvar(filout, v1) ; 
    nc_varput(filout, v1.Name, squeeze(vwnddat(i,:,:,:))) ; 
    nc_attput(filout, v1.Name, 'units', 'm sec^-^1') ; 
    nc_attput(filout, v1.Name, 'longname', 'UWND') ; 
    nc_attput(filout, v1.Name, 'Notes', 'Forced or Coupled Response Only; Annual mean is NOT removed')
        
    v1.Name = 'H' ; 
    v1.Datatype = 'double' ; 
    v1.Dimension = {'time', 'lat', 'lon'} ; 
    nc_addvar(filout, v1) ; 
    nc_varput(filout, v1.Name, squeeze(tcdat(i,:,:,:))) ; 
    nc_attput(filout, v1.Name, 'units', 'm') ; 
    nc_attput(filout, v1.Name, 'longname', 'Thermocline Depth') ; 
    nc_attput(filout, v1.Name, 'Notes', 'Annual mean is NOT removed')
 
end


